==> ark-17.04.2.tar.xz: ark-17.04.2/plugins/libarchive/kerfuffle_libarchive.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for compressed TAR archives",
        "Description[ca@valencia]": "Implementació completa dels arxius TAR comprimits",
        "Description[ca]": "Implementació completa dels arxius TAR comprimits",
        "Description[cs]": "Plná podpora komprimovaných archivů TAR",
        "Description[de]": "Vollständige Unterstützung für komprimierte TAR-Archive",
        "Description[el]": "Πλήρης υποστήριξη για την αρχειοθήκη μορφής TAR",
        "Description[es]": "Uso total de los archivos comprimidos TAR",
        "Description[eu]": "Konprimatutako TAR artxiboentzako euskarri osoa",
        "Description[fr]": "Prise en charge complète des archives compressées TAR",
        "Description[it]": "Supporto completo per archivi compressi TAR",
        "Description[nl]": "Volledige ondersteuning voor gecomprimeerde TAR-archieven",
        "Description[pl]": "Pełna obsługa dla formatów archiwów TAR",
        "Description[pt]": "Suporte total para pacotes comprimidos do TAR",
        "Description[sk]": "Plná podpora komprimovaných archívov TAR",
        "Description[sl]": "Polna podpora za arhive vrste TAR",
        "Description[sr@ijekavian]": "Пуна подршка за компресоване тар архиве",
        "Description[sr@ijekavianlatin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr@latin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr]": "Пуна подршка за компресоване тар архиве",
        "Description[sv]": "Fullt stöd för komprimerade TAR-arkiv",
        "Description[uk]": "Повноцінна підтримка стиснених архівів TAR",
        "Description[x-test]": "xxFull support for compressed TAR archivesxx",
        "Description[zh_CN]": "完全支持压缩的 TAR 归档",
        "Description[zh_TW]": "對壓縮過的 TAR 壓縮檔的完整支援",
        "Id": "kerfuffle_libarchive",
        "MimeTypes": [
            "@SUPPORTED_READWRITE_MIMETYPES@"
        ],
        "Name": "Libarchive plugin",
        "Name[ca@valencia]": "Connector del Libarchive",
        "Name[ca]": "Connector del Libarchive",
        "Name[cs]": "Modul libarchive",
        "Name[de]": "LibArchive-Modul",
        "Name[el]": "Πρόσθετο Libarchive",
        "Name[es]": "Complemento Libarchive",
        "Name[eu]": "Libarchive plugina",
        "Name[fr]": "Module externe libarchive",
        "Name[it]": "Estensione Libarchive",
        "Name[nl]": "LibArchive-plug-in",
        "Name[pl]": "Wtyczka libarchive",
        "Name[pt]": "'Plugin' da Libarchive",
        "Name[sk]": "Plugin Libarchive",
        "Name[sl]": "Vstavek Libarchive",
        "Name[sr@ijekavian]": "Прикључак за Либархив",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive",
        "Name[sr@latin]": "Priključak za libarchive",
        "Name[sr]": "Прикључак за Либархив",
        "Name[sv]": "Libarchive-insticksprogram",
        "Name[uk]": "Додаток libarchive",
        "Name[x-test]": "xxLibarchive pluginxx",
        "Name[zh_CN]": "Libarchive 插件",
        "Name[zh_TW]": "Libarchive 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 100,
    "application/x-bzip-compressed-tar": {
        "CompressionLevelDefault": 9,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lrzip-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lz4-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lzip-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-lzma-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-tzo": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-xz-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    }
}

==> ark-17.04.3.tar.xz: ark-17.04.3/plugins/libarchive/kerfuffle_libarchive.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for compressed TAR archives",
        "Description[ca@valencia]": "Implementació completa dels arxius TAR comprimits",
        "Description[ca]": "Implementació completa dels arxius TAR comprimits",
        "Description[cs]": "Plná podpora komprimovaných archivů TAR",
        "Description[de]": "Vollständige Unterstützung für komprimierte TAR-Archive",
        "Description[el]": "Πλήρης υποστήριξη για την αρχειοθήκη μορφής TAR",
        "Description[es]": "Uso total de los archivos comprimidos TAR",
        "Description[eu]": "Konprimatutako TAR artxiboentzako euskarri osoa",
        "Description[fr]": "Prise en charge complète des archives compressées TAR",
        "Description[it]": "Supporto completo per archivi compressi TAR",
        "Description[nl]": "Volledige ondersteuning voor gecomprimeerde TAR-archieven",
        "Description[pl]": "Pełna obsługa dla formatów archiwów TAR",
        "Description[pt]": "Suporte total para pacotes comprimidos do TAR",
        "Description[sk]": "Plná podpora komprimovaných archívov TAR",
        "Description[sl]": "Polna podpora za arhive vrste TAR",
        "Description[sr@ijekavian]": "Пуна подршка за компресоване тар архиве",
        "Description[sr@ijekavianlatin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr@latin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr]": "Пуна подршка за компресоване тар архиве",
        "Description[sv]": "Fullt stöd för komprimerade TAR-arkiv",
        "Description[tr]": "Sıkıştırılmış TAR arşivleri için tam destek",
        "Description[uk]": "Повноцінна підтримка стиснених архівів TAR",
        "Description[x-test]": "xxFull support for compressed TAR archivesxx",
        "Description[zh_CN]": "完全支持压缩的 TAR 归档",
        "Description[zh_TW]": "對壓縮過的 TAR 壓縮檔的完整支援",
        "Id": "kerfuffle_libarchive",
        "MimeTypes": [
            "@SUPPORTED_READWRITE_MIMETYPES@"
        ],
        "Name": "Libarchive plugin",
        "Name[ca@valencia]": "Connector del Libarchive",
        "Name[ca]": "Connector del Libarchive",
        "Name[cs]": "Modul libarchive",
        "Name[de]": "LibArchive-Modul",
        "Name[el]": "Πρόσθετο Libarchive",
        "Name[es]": "Complemento Libarchive",
        "Name[eu]": "Libarchive plugina",
        "Name[fr]": "Module externe libarchive",
        "Name[it]": "Estensione Libarchive",
        "Name[nl]": "LibArchive-plug-in",
        "Name[pl]": "Wtyczka libarchive",
        "Name[pt]": "'Plugin' da Libarchive",
        "Name[sk]": "Plugin Libarchive",
        "Name[sl]": "Vstavek Libarchive",
        "Name[sr@ijekavian]": "Прикључак за Либархив",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive",
        "Name[sr@latin]": "Priključak za libarchive",
        "Name[sr]": "Прикључак за Либархив",
        "Name[sv]": "Libarchive-insticksprogram",
        "Name[tr]": "Libarchive eklentisi",
        "Name[uk]": "Додаток libarchive",
        "Name[x-test]": "xxLibarchive pluginxx",
        "Name[zh_CN]": "Libarchive 插件",
        "Name[zh_TW]": "Libarchive 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 100,
    "application/x-bzip-compressed-tar": {
        "CompressionLevelDefault": 9,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lrzip-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lz4-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lzip-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-lzma-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-tzo": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-xz-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    }
}
